@@ -19,10 +19,6 @@
         <source>Passed address is not a local device.</source>
         <translation>Übergebene Adresse gehört zu keinem lokalen Gerät.</translation>
     </message>
-    <message>
-        <source>Missing Location permission. Search is not possible.</source>
-        <translation>Die Berechtigung zur Positionsbestimmung fehlt. Es ist keine Suche möglich.</translation>
-    </message>
     <message>
         <source>Location service turned off. Search is not possible.</source>
         <translation>Standortbestimmung abgeschaltet. Suche ist nicht möglich.</translation>
@@ -880,6 +876,10 @@
         <extracomment>Environmental sensing related</extracomment>
         <translation>Database Change Increment</translation>
     </message>
+    <message>
+        <source>Weight Scale Feature</source>
+        <translation>Waagendaten</translation>
+    </message>
     <message>
         <source>Server Characteristic Configuration</source>
         <translation>Charakteristische Konfiguration des Servers</translation>
@@ -1434,10 +1434,6 @@
         <source>Error occurred trying to connect to remote device.</source>
         <translation>Beim Aufbau der Verbindung zum Gerät trat ein Fehler auf.</translation>
     </message>
-    <message>
-        <source>Error missing permission</source>
-        <translation>Fehler: Fehlende Berechtigung</translation>
-    </message>
     <message>
         <source>Failed to authorize on the remote device</source>
         <translation>Fehler bei Autorisierung auf dem Gerät</translation>
@@ -1446,6 +1442,10 @@
         <source>Missing permissions error</source>
         <translation>Fehler: Fehlende Berechtigungen</translation>
     </message>
+    <message>
+        <source>Error reading RSSI value</source>
+        <translation>Fehler beim Lesen des RSSI-Werts</translation>
+    </message>
     <message>
         <source>Error occurred trying to start advertising</source>
         <translation>Bei der Ankündigung trat ein Fehler auf</translation>
